import React from 'react'
import PropTypes from 'prop-types'
import styled from 'styled-components'

const Button = styled.input`
  color: #fff;
  background-color: #0e2f43;
  border: none;
  font-size: 24px;
  line-height: 34px;
  height: 34px;
  padding: 0;
  width: 34px;
  margin: 1px;
  
  &:hover {
    background-color: #2d8891;
  }
`

const TextField = styled.input`
  color: #000;
  background-color: #eee;
  border: none;
  font-size: 24px;
  line-height: 34px;
  height: 34px;
  padding: 0;
  text-align: center;
  width: 10em;
  margin: 1px;
  box-sizing: border-box;

  
  &:focus {
     border: 1px solid #2d8891;
  }
`

const Div = styled.div`
  border: 1px dotted #aaa;
  background-color: #eee;
  font-family: monospace;
  padding: 1em;
`

const RouteTile = ({title, stops, onAdd, url, onDelete, onClear}) => {
  let input
  let output

  return stops.length == 0 && url === undefined ?
  <div>
      <h2>{title}</h2>
      <form onSubmit={(e) => {
        e.preventDefault()
        if (input.value.trim() == "") {
          return
        }
        onAdd(input.value.trim())
        input.value = ""
      }}>
        <TextField type="text" placeholder="Add link to route" ref={node => {input = node}} />
        <Button type="submit" value="+" />
      </form>
  </div>
  :
  <div>
    { url === undefined && <Button style={{float: 'right'}} onClick={onDelete} type="button" value="-" /> }
    { url === undefined && <Button style={{float: 'right'}} onClick={onClear} type="button" value="&#x1F589;" /> }
    <h2>{title}</h2>
    { url !== undefined && <Div
        onClick={(e) => {
          var range = document.createRange();
          range.selectNode(e.currentTarget);
          window.getSelection().removeAllRanges();
          window.getSelection().addRange(range);
        }} className="url">{url}</Div> }
    <ul>
      {stops.map((stop, i) => (
        <li key={i}>{stop}</li>
      ))}
    </ul>
  </div>
}

RouteTile.propTypes = {
  stops: PropTypes.arrayOf(PropTypes.string).isRequired,
  url: PropTypes.string,
  onAdd: PropTypes.func,
  onDelete: PropTypes.func,
  onClear: PropTypes.func,
  title: PropTypes.string.isRequired,
}

export default RouteTile
